@@ -5,6 +5,7 @@ Deploy services in either Google Cloud Run or CDF Functions.
 Model registry uses CDF Files.
 """ 
 import os
+import traceback
 
 import shutil
 import subprocess
@@ -144,16 +145,15 @@ def deploy(model_settings):
                 else:
                     logging.warning("No test file was set up. " \
                                     "End-to-end test skipped!")
-        except Exception as error:
-            error_type = type(error).__name__
-            error_message = f"Model failed to deploy!\n{error_type}\n{error}"
+        except Exception:
+            trace = traceback.format_exc()
+            error_message = f"Model failed to deploy!\n{trace}"
             logging.error(error_message)
             failed_models[model_name] = error_message
 
         finally:
             logging.debug(f"cd ..")
-            if os.path.isdir(base_path):
-                os.chdir(base_path)
+            os.chdir(base_path)
             logging.debug(f"Delete deployment folder")
             if os.path.isdir(deployment_folder):
                 shutil.rmtree(deployment_folder)
